/* 
This .do file consists of three parts.  In the first part, I read in the data,
which was produced by SAS.  In the second part, I create the tables related to the
hypothesis that acquired plants start producing the products that the acquiring 
firm had already been producing.  In the third part, I create the tables related to the
hypothesis that acquired plants begin shipping to the zip codes that the acquiring firm
had already been shipping to.  

The second part relates to Table 6 Panel A, A7, and A9 of Vertical Integration and Input Flows. 
The third part relates to Table 6 Panel B, A8, and A10 of the paper.
*/

clear
clear matrix
set more off
set mem 5g

local getdata=0   /* do we run the part of the code that reads in the data? */
local custlists=1  /* do we run the part of the code that analyzes shipment destinations (pre/post change of ownership) ? */
local products=0   /* do we run the part of the code that analyzes prdocution (pre/post change of ownership) ? */

if `getdata'==1 {

/* Note this dataset is produced by getdata12.sas. It contains the list
   of fraction of sales that are vertically & internal 
   to the firm, 1997  */

insheet using two10.csv, clear  /* Bring in the dataset of vertical relationships.  The point of this is 
                       to  test whether the intangible asset effects are larger for plants with vertical shipments.*/
keep if year==1997
gen val=vs*cfs_wgt 
sort rec_num
by rec_num: gen x=1 if _n==1  /* Keep one observation per shipment.  If the shipment is not internal,
                                then the rec_num variatble will be missing  */
keep if x==1 | rec_num==.
collapse (sum) val (min) totalval, by(lbdnum)
gen fracInternal=val/totalval
drop val totalval
save internalshare97, replace

insheet using three10A.csv, clear  /* Bring in the dataset of vertical relationships */
keep if year==1997
gen val=vs*cfs_wgt 
sort rec_num
by rec_num: gen x=1 if _n==1  /* Keep one observation per shipment.  If the shipment is not internal,
                            then the rec_num variatble will be missing  */

keep if x==1 | rec_num==.
collapse (sum) val (min) totalval, by(lbdnum)
gen fracInternal=val/totalval
drop val totalval
save internalshare97_liberal, replace

foreach name in FullSamp Group  {  /* Read in production/merger data.    */
  insheet using prod`name'87.csv, clear
  cap drop cfn
  save prod`name'87, replace
  insheet using prod`name'92.csv, clear
  cap drop cfn
  save prod`name'92, replace
  insheet using prod`name'OCD87.csv, clear
  cap drop cfn
  save prod`name'OCD87, replace
  insheet using prod`name'OCD92.csv, clear
  cap drop cfn
  save prod`name'OCD92, replace
  use prod`name'87
  gen samp=0
  append using prod`name'92
  replace samp=1 if samp==.
  save prod`name', replace
  use prod`name'OCD87
  gen samp=0
  append using prod`name'OCD92
  replace samp=1 if samp==.
  save prod`name'OCD, replace
}
rm prodFullSamp87.csv  
rm prodFullSamp92.csv
rm prodFullSampOCD87.csv
rm prodFullSampOCD92.csv
rm prodFullSamp87.dta
rm prodFullSamp92.dta
rm prodFullSampOCD87.dta
rm prodFullSampOCD92.dta

insheet using cfsFullSamp.csv, clear
drop sic2 sic3 sic4 
save cfsFullSample, replace
insheet using cfsFullSampOCD.csv, clear
drop sic2 sic3 sic4 
save cfsFullSampleOCD, replace
rm cfsFullSamp.csv
rm cfsFullSampOCD.csv

use ../../data/zipcodes, replace
by zipcode: keep if _n==1
keep zipcode countyfips
save zipCounty, replace

insheet using ../../data/outside/eacodes.txt, delim(" ") clear
keep v1 v3
ren v1 ea
ren v3 countyfips
bys countyfips: keep if _n==1
merge 1:n countyfips using zipCounty
drop in 1/1
/* A couple of the counties have missing info. on Economic 
Areas.  Fill these in, manually */
replace ea=171  if countyfips==2068
replace ea=171  if countyfips==2232
replace ea=171  if countyfips==2282 
replace ea=141  if countyfips==8014
replace ea=31  if countyfips==12086
drop _merge
drop if zipcode==.
save zipEAcounty, replace

use ../../data/zipcodes, replace
drop zipcodetype-dst
bys zipcode: keep if _n==1
save zipcodes, replace

}

if `products'==1 {
/*qq indexes which method to identify mergers is used.  When qq=1, we use the method that is identified the paper.  When qq=2, we use Ngyuen's Ownership Change database */
forvalues qq=1/2 {  
local suff= ""
if `qq'==2 {
  local suff="OCD"
}
use prodGroup`suff', replace
ren curbefore curpc
drop if mrgeyr==1997 | mrgeyr==1986
qui sum year if piship==.  /* For the industries for which piship is missing, impte piship using the average price index for that year */
local y=r(mean)
qui sum piship if year==`y'
replace piship=r(mean) if piship==.
replace year=year-5 if samp==1
foreach var of varlist val* {
  replace `var'=0 if `var'==.
}
replace valown=valown-valueplant
gen group1=(valown>0)
gen group2=(valbuyer>0)
gen group=group2*2+group1
replace value=value/piship
forvalues x=0/3 {
  gen value`x'=value*(group==`x')
}
collapse (sum) value*, by(lbdnum year)
drop valueplant
forvalues x=0/3 {
   gen frac`x'=value`x'/value
   bys year: egen Val`x'=mean(value`x')
}
collapse (mean) Val* frac* [aw=value] , by(year)
outsheet using prodGroupResults_`suff'.csv, replace delim(,)

use prodFullSamp`suff', replace

drop if mrgeyr==1997 | mrgeyr==1986
foreach var of varlist val* {
   replace `var'=0 if `var'==.
}

sort lbdnum curpc samp
by lbdnum curpc samp: egen s1=sum(valueplant)
drop valueplant
ren s1 valueplant
by lbdnum curpc samp: keep if _n==1
replace mixweightthis=0 if mixweightthis==.
replace valownfirm_6=round(valownfirm_6-valueplant6)
replace valownfirm=round(valownfirm-valueplant*mixweightthis)

gen pastYes6=(valueplant6>0)
gen pastYes7=(valueplant>0)
gen yesOwnF7=(valownfirm>0)
gen yesOwnF6=(valownfirm_6>0)
gen yesBuyerF7=(valbuyer>0)
gen yesBuyerF6=(valbuyer_6>0)
gen yes=(value>0)

gen interaction7=pastYes7*yesBuyerF7
gen interaction6=pastYes6*yesBuyerF6

gen lvalProd=log(valtotal-value)
gen mrgeyrMod=mod(mrgeyr, 5)

gen year=1987
replace year=1992 if mrgeyr>1992

local varlist1="pastYes6 pastYes7 lvalProd"
local varlist2="pastYes6 pastYes7 lvalProd yesOwnF6 yesBuyerF6"
local varlist3="pastYes6 pastYes7 lvalProd yesOwnF6 yesBuyerF6 yesOwnF7 yesBuyerF7"
local varlist4="pastYes6 pastYes7 lvalProd yesOwnF6 yesBuyerF6 yesOwnF7 yesBuyerF7"
local varlist5="pastYes6 pastYes7 lvalProd yesOwnF6 yesBuyerF6 yesOwnF7 yesBuyerF7"
local varlist5="pastYes6 pastYes7 lvalProd yesOwnF6 yesBuyerF6 yesOwnF7 yesBuyerF7"
local varlist6="pastYes6 pastYes7 lvalProd yesOwnF6 yesBuyerF6 yesOwnF7 yesBuyerF7"
local varlist7="pastYes6 pastYes7 lvalProd yesBuyerF6 yesBuyerF7"
local cond1=" "
local cond2=" "
local cond3=" "
local cond4="if mod(mrgeyr,5)==2 | mod(mrgeyr,5)==3 | mod(mrgeyr,5)==4 "
local cond5="if mod(mrgeyr,5)==0 | mod(mrgeyr,5)==1"
local cond6="if mubefore==1"
local cond7="if mubefore==0"

sort lbdnum
by lbdnum: gen id=1 if _n==1  /* Create an id variable, distinct for each lbdnum */
replace id=sum(id)
gen cur3=substr(curpc,1,3)
gen cur4=substr(curpc,1,4)
destring cur3, replace force
destring cur4, replace force
gen double idThree=id*1000000+cur3*100+samp  /* Create the "group" variables.  Remember that samp was a variable created by sas
                                               which is equal to 1 if the merger occurred in 1992-1996 and 0 if the merger occurred 
                                              in 1987-1991 */
gen double idFour=id*1000000+cur4*100+samp
bys idThree: egen sYes=sum(yes)
by idThree: gen x=_N
drop if x==sYes | sYes==0
drop x sYes
xtset idFour
forvalues x=1/14{
  local xg=mod(`x',7)
  if `xg'== 0 {
    local xg=7
  } 
  if `x'==8 {
   xtset idThree
  } 
  gen coef`x'=.
  xtlogit yes `varlist`xg''  `cond`xg'', fe
  replace coef`x'=e(r2_p) in 22/22
  replace coef`x'=e(N) in 23/23
  replace coef`x'=e(N_g) in 24/24
  gen esamp=1 if e(sample)
  if `x'==1 {
    save esum_prod_`suff', replace
  }
  sum yes  if e(sample) 
  replace coef`x'=r(mean) in 25/25

 forvalues gg=1/7 {
     local rm`gg'=0
  }
  sum pastYes6 if esamp==1
  local rm1=r(mean)
  sum pastYes7 if esamp==1
  local rm2=r(mean)
  sum lvalProd if esamp==1
  local rm3=r(mean)
  sum yesOwnF6 if esamp==1
  local rm4=r(mean)
  sum yesBuyerF6 if esamp==1
  local rm5=r(mean)
  sum yesOwnF7 if esamp==1
  local rm6=r(mean)
  sum yesBuyerF7 if esamp==1
  local rm7=r(mean)
  if `x'==1 | `x'==8 {                              /* Here I am estimating the average value of XB for an establishment where all indicators are 0 and lvalprod is equal to 0.  I do so by taking the average probability of success for plants with all indicators equal to 0, and lvalProd close to the sample mean, and then subtracting off the effect of going from lvalProd = sample mean to lvalProd =0 .   */
    sum yes if abs(lvalProd-`rm3')<.15 &  esamp==1 & pastYes6==0
    local baselineXB=logit(r(mean))-`rm3'*_b[lvalProd]
  }
  if `x'==7 | `x'==14 {
    sum yes if abs(lvalProd-`rm3')<.15 &  esamp==1 & pastYes6==0 & yesBuyerF6==0
    local baselineXB=logit(r(mean))-`rm3'*_b[lvalProd]
  }
  if `x'~=1 & `x'~=8 & `x'~=7 & `x'~=14 {
    sum yes if abs(lvalProd-`rm3')<.15 & esamp==1 & pastYes6==0  & yesOwnF6==0 & yesBuyerF6==0
    local baselineXB=logit(r(mean)) -`rm3'*_b[lvalProd]
  }
  di `baselineXB' 
  local z=wordcount("`varlist`xg''")
  forvalues xx=1/`z' {
     local zz=word("`varlist`xg''",`xx')
     local y=3*`xx'-2  /* For each variable, we store the coefficient estimate, standard error, and marginal effect. This explains the factor of "3"  */
     local yy=3*`xx'-1
     local yyy=3*`xx'
     qui replace coef`x'=_b[`zz'] in `y'/`y'
     qui replace coef`x'=_se[`zz'] in `yy'/`yy'
      local xbsum=`baselineXB'
      forvalues yqq=1/`z' {
        local zzz=word("`varlist`xg''",`yqq')  
        local yqq2=`yqq'
        if `xg'==7 & `yqq'>3 {   /* When xx=7 or 14, the variables yesOwnF6 and yesOwnF7 are not included in the regression.  This causes a mismatch between the 
                                   suffix of the rm variables and their place in the "varlist" list.  This little piece of code corrects for this mismatch */
            local yqq2=2*`yqq'-3
        }
        local xbsum=`xbsum'+_b[`zzz']*`rm`yqq2''  
      }
      /* At this point, xbsum should be equal to XB, evaluated at the mean value of all variables (for the "average" establishment X EA/county group ) */
      if `xx'==1 {                
            local xbsum=`xbsum'-_b[pastYes7]*`rm2'       
       }
      if `xx'==2 { 
            local xbsum=`xbsum'+_b[pastYes6]*(1-`rm1')       
       }
     if `xg'==7 {
         if `xx'==4 { 
            local xbsum=`xbsum'-_b[yesBuyerF7]*`rm7'       
         }
         if `xx'==5 { 
            local xbsum=`xbsum'+_b[yesBuyerF6]*(1-`rm5')       
         }
     }
     if `xg'~=7 {   
          if `xx'==7 { 
            local xbsum=`xbsum'+_b[yesBuyerF6]*(1-`rm5')       
         }
          if `xx'==6 { 
            local xbsum=`xbsum'+_b[yesOwnF6]*(1-`rm4')       
         }
          if `xx'==4 & `xg'~=2 { 
            local xbsum=`xbsum'-_b[yesBuyerF7]*`rm7'
         }
          if `xx'==5 & `xg'~=2 { 
            local xbsum=`xbsum'-_b[yesOwnF7]*`rm6'
         }
     }
     if `xx'~=3  {
         local xbsum=`xbsum'-_b[`zz']*`rm`xx''  /* Set the own variable to 0 */
         local mrgB=exp(`xbsum'+_b[`zz'])/(1+exp(`xbsum'+_b[`zz']))-exp(`xbsum')/(1+exp(`xbsum'))  /* For indicator variables, compute the marginal effect as the difference ofPr(Y=1) evaluated at 0 and 1 for the independent variable of interest */
     }
     if `xx'==3 {
         local mrgB=exp(`xbsum')*(1+exp(`xbsum'))^(-2)*_b[`zz'] /* For continuous variables, use the forumla from page 815 of the Greene textbook */
     }   
     qui replace coef`x'=`mrgB' in `yyy'/`yyy' 
   }
  /* drop esamp */
  ren esamp esamp`x'
  list coef* in 1/25
 }
keep coef* 
keep in 1/25
outsheet using prodResults_`suff'.csv, delim(,) replace
  }
}

if `custlists'==1 {

forvalues qq=1/2 {  /* qq indexes which method to identify mergers is used.  When qq=1, we use the method that is identified the paper.  When qq=2, we use Ngyuen's Ownership Change database */

local suff= ""
if `qq'==2 {
  local suff="OCD"
}
local wwww=2-`qq'  /* When using the Ownership Change Database, do not consider wholesale establishments */
forvalues whole=0/`wwww' {
insheet using cfsGroup`suff'.csv, clear
if `qq'== 1 {
  if `whole'==1 {
     keep if sic2>=50 & sic2<=59  
  }
  if `whole'==0 {
    drop if sic2>=50 & sic2<=59
  }
}
foreach var of varlist val* {
  replace `var'=0 if `var'==.
}
replace valown=valown-valueplant
gen group1=(valown>0)  
gen group2=(valbuyer>0)
gen group=group2*2+group1
forvalues x=0/3 {
  gen value`x'=value*(group==`x')
}
collapse (sum) value*, by(lbdnum year)
replace value=value/1.046 if year==1997 /* Change in PPI from 7/93 to 7/97 according to FRED */
drop valueplant
forvalues x=0/3 {
   gen frac`x'=value`x'/value
   bys year: egen Val`x'=mean(value`x')
}
collapse (mean) Val* frac* [aw=value] , by(year)
outsheet using cfsGroupResults_`suff'_`whole'.csv, replace delim(,)
}

use cfsFullSample`suff', replace
drop if mrgeyr==1997 
foreach var of varlist val* {
  replace `var'=0 if `var'==.
}
foreach var of varlist valown* {
  replace `var'=`var'-valueplant  /* To get the value sent by other plant's in the original firm, subtract off the value sent by the plant itself */
}
gen byte pastYes=(valueplant>0)  /* valueplant contains the value sent by the plant in 1993.  */
forvalues x=2(2)4 {
  gen byte yesOwnF`x'=(valownfirm_`x'>0)  /* These variables capture the amount sent, in 1993, by plants that are in the same 2 (or 4) digit SIC and are either a) other plants in the original firm or b) plants from the purchasing firm */
  gen byte yesBuyerF`x'=(valbuyer_`x'>0)
}
gen byte yesOwnF=(valownfirm>0) 
gen byte yesBuyerF=(valbuyer>0)
gen lvalZIP=log(valtotal-value) /* To get the total value shipped (in 1997) to a given zip code by other plants, subtract off the value shipped by the own plant */
gen yes=(value>0)
drop valueplant valown* valbuyer* value 
ren dest_zip zipcode 
merge n:1 zipcode using zipEAcounty, keep(3) /* Merge in data on the Economic Areas of each destination zip code */
drop _merge
sort lbdnum ea
by lbdnum ea: gen zz=_N
by lbdnum ea: egen sYes=sum(yes) /* Count the number  positive values per group.  Droup groups where all or none of the observations are equal to 1*/
drop if sYes==0 | zz==sYes /* These would be dropped by the xtlogit command anyway */
drop sYes
ren zipcode dest_zip
ren firmdown dYes
replace dYes=0 if dYes==.

/* Get distances */

ren dest_zip zipcode 
merge n:1 zipcode using zipcodes,  keep(1 3)
ren zipcode dest_zip
ren longit dest_longit
ren latit dest_latit
drop _merge
ren orig_zip zipcode
merge n:1 zipcode using zipcodes, keep(1 3)
ren zipcode orig_zip
ren longit orig_longit
ren latit orig_latit

/* There are a small number of zip codes with 
missing longitude/latitude.  Get the 
zip code that is "closest" (according to the number of the zip code)
and fillin the longitude and latitude from this close zip code */
gen nomiss=1-(orig_latit==.)
sort nomiss orig_zip
by nomiss orig_zip: gen idTemp=1 if _n==1
replace idTemp=sum(idTemp)
forvalues xq=1/10 {
   qui sum orig_zip if idTemp==`xq'
   local oo=r(mean)  /* Get the identity of the zip code */
   qui sum orig_zip if orig_zip>`oo' & nomiss==1 /* Get the identity of the "next" zip code which doesn't have a missing value */
   local oo2=r(min)
   qui sum orig_latit if orig_zip==`oo2'
   replace orig_latit=r(mean) if orig_latit==. & orig_zip==`oo'
   qui sum orig_longit if orig_zip==`oo2'
   replace orig_longit=r(mean) if orig_longit==. & orig_zip==`oo'
}

drop nomiss idTemp
drop if dest_latit==. /* There shouldn't be any of these zip codes, but just in case */
gen mileage2=sqrt( 69.31^2 * (dest_latit-orig_latit)^2 + 53.0^2 * (dest_longit-orig_longit)^2)/1000
drop _merge

gen miss=(lvalZIP==.)
bys dest_zip: egen mm=max(miss)
drop if mm==1
drop mm miss

merge n:1 lbdnum using internalshare97_liberal , keep(1 3)  
ren fracInternal fracInternal_liberal
replace fracInternal_liberal=0 if fracInternal_liberal==.
drop _merge

merge n:1 lbdnum using internalshare97 , keep(1 3)  
replace fracInternal=0 if fracInternal==.

bys lbdnum: gen double id=1 if _n==1
replace id=sum(id)
gen double idEA=id*100000+ea  /* Create groups of idX Economic Area of idX Coutny*/
gen double idcou=id*100000+countyfips
gen lmileage2=log(mileage2)
qui sum lmileage2
/* What if orig_zip==dest_zip (and mileage==0)?  Just set the value to the minimum
   observed for orig_zip~=dest_zip */
replace lmileage2=r(min) if lmileage2==.
compress 

/* varlistX gives the variables used in the Xth regression.  Same idea for condX, the conditions for the Xth regression */

local varlist1="pastYes lvalZIP dYes lmileage2"
local varlist2="pastYes lvalZIP dYes lmileage2 yesOwnF yesBuyerF" 
local varlist3="pastYes lvalZIP dYes lmileage2 yesOwnF yesBuyerF yesOwnF2 yesBuyerF2"
local varlist4="pastYes lvalZIP dYes lmileage2 yesOwnF yesBuyerF yesOwnF2 yesBuyerF2 yesOwnF4 yesBuyerF4" 
local varlist5="pastYes lvalZIP dYes lmileage2 yesOwnF yesBuyerF yesOwnF2 yesBuyerF2 yesOwnF4 yesBuyerF4" 
local varlist6="pastYes lvalZIP dYes lmileage2 yesOwnF yesBuyerF yesOwnF2 yesBuyerF2 yesOwnF4 yesBuyerF4" 
local varlist7="pastYes lvalZIP dYes lmileage2 yesOwnF yesBuyerF yesOwnF2 yesBuyerF2 yesOwnF4 yesBuyerF4" 
local varlist8="pastYes lvalZIP dYes lmileage2 yesOwnF yesBuyerF yesOwnF2 yesBuyerF2 yesOwnF4 yesBuyerF4" 
local varlist9="pastYes lvalZIP dYes lmileage2 yesOwnF yesBuyerF yesOwnF2 yesBuyerF2 yesOwnF4 yesBuyerF4" 
local varlist10="pastYes lvalZIP dYes lmileage2 yesOwnF yesBuyerF yesOwnF2 yesBuyerF2 yesOwnF4 yesBuyerF4"
local varlist11="pastYes lvalZIP dYes lmileage2 yesOwnF yesBuyerF yesOwnF2 yesBuyerF2 yesOwnF4 yesBuyerF4"
local varlist12="pastYes lvalZIP dYes lmileage2 yesBuyerF  yesBuyerF2 yesBuyerF4"
local cond1=" "
local cond2=" "
local cond3=" "
local cond4=" "
local cond5=" (mrgeyr==1992 | mrgeyr==1993 | mrgeyr==1994) & " 
local cond6=" (mrgeyr==1995 | mrgeyr==1996) & "
local cond7=" fracInternal>0 & "
local cond8=" fracInternal==0 &"  
local cond9=" fracInternal_liberal>0 & "
local cond10=" fracInternal_liberal==0 &"  
local cond11=" mu93>0 & "
local cond12=" mu93==0 &"  
gen wholesale=(bestsic>=500000 & bestsic<600000)  /* note this includes a few wholesale-like retail establishments, like mail-order catalogues*/

forvalues whole=0/`wwww' {
local coefname="coef"
if `whole'==1 {
   local coefname="coefWhole"
}
xtset idcou
 /* There will be 24 regressions, in the first 12 the group variable is idXcounty.  In the next 12 the group variable is idXEA*/
foreach x in 1 7 8 9 10 { 
  local xg=mod(`x',12)
  if `xg'== 0 {
    local xg=12
  } 
  if `x'==13 {
   xtset idEA
  } 
  gen `coefname'`x'=.
  if `qq'==1 {
     xtlogit yes `varlist`xg'' if  `cond`xg''  wholesale==`whole', fe
  }
  if `qq'==2 {
     xtlogit yes `varlist`xg'' if  `cond`xg''  wholesale<., fe
  }
  replace `coefname'`x'=e(r2_p) in 31/31
  replace `coefname'`x'=e(N) in 32/32
  replace `coefname'`x'=e(N_g) in 33/33
  gen esamp=1 if e(sample)
  if `x'==1 {
    save esum_cust_`whole'_`suff', replace
  }
  sum yes  if e(sample) & wholesale==`whole'
  replace `coefname'`x'=r(mean) in 34/34

 forvalues gg=1/10 {
     local rm`gg'=0
  }
  sum pastYes if esamp==1  /* Store the sample mean of each of the independent variables, for later use (in particular to compute 
                           marginal effects */
  local rm1=r(mean)
  sum lvalZIP if esamp==1
  local rm2=r(mean)
  sum dYes if esamp==1
  local rm3=r(mean)
  sum lmileage2 if esamp==1
  local rm4=r(mean)
  sum yesOwnF if esamp==1
  local rm5=r(mean)
  sum yesBuyerF if esamp==1
  local rm6=r(mean)
  sum yesOwnF2 if esamp==1
  local rm7=r(mean)
  sum yesBuyerF2 if esamp==1
  local rm8=r(mean)
  sum yesOwnF4 if esamp==1
  local rm9=r(mean)
  sum yesBuyerF4 if esamp==1
  local rm10=r(mean)

  if `x'==1 | `x'==13 {
    sum yes if abs(lvalZIP-`rm2')<.15 &  abs(lmileage2-`rm4')<.15 &  esamp==1 & dYes==0 & pastYes==0
    local baselineXB=logit(r(mean))-`rm2'*_b[lvalZIP] -`rm4'*_b[lmileage2]                                  
  }
  if `x'==12 | `x'==24 {
    sum yes if abs(lvalZIP-`rm2')<.15 &  abs(lmileage2-`rm4')<.15 &  esamp==1 & dYes==0 & pastYes==0 & yesBuyerF==0
    local baselineXB=logit(r(mean))-`rm2'*_b[lvalZIP] -`rm4'*_b[lmileage2]                                  
  }
  if `x'~=1 & `x'~=13 & `x'~=12 & `x'~=24 {
    sum yes if abs(lvalZIP-`rm2')<.15 & abs(lmileage2-`rm4')<.15  & esamp==1 &  dYes==0 & pastYes==0  & yesOwnF==0 & yesBuyerF==0
    local baselineXB=logit(r(mean)) -`rm2'*_b[lvalZIP] -`rm4'*_b[lmileage2]    
  }
  di `baselineXB' 
  local z=wordcount("`varlist`xg''")
  forvalues xx=1/`z' {
     local zz=word("`varlist`xg''",`xx')
     local y=3*`xx'-2
     local yy=3*`xx'-1
     local yyy=3*`xx'
     qui replace `coefname'`x'=_b[`zz'] in `y'/`y'
     qui replace `coefname'`x'=_se[`zz'] in `yy'/`yy'
      local xbsum=`baselineXB'
      forvalues yqq=1/`z' {
        local zzz=word("`varlist`xg''",`yqq')
        local yqq2=`yqq'
        if `xg'==12 & `yqq'>4 {
            local yqq2=2*`yqq2'-4
        }
        local xbsum=`xbsum'+_b[`zzz']*`rm`yqq''
      }
     /* If we are calculating the marginal effect of a j group for j in 2/4, set the groups smaller than j to 1
        and the groups larger than j to 0.
     */
    if `xg'~=12  {
     if `xx'==5 {
       forvalues ggg=7(2)`z' {
       local zzz=word("`varlist`xg''",`ggg')
       local xbsum=`xbsum'-`rm`ggg''*_b[`zzz']
       }
     }
     if `xx'==6 {
       forvalues ggg=8(2)`z' {
       local zzz=word("`varlist`xg''",`ggg')
       local xbsum=`xbsum'-`rm`ggg''*_b[`zzz']
       }
     }
     if `xx'>6 {
       if mod(`xx',2)==0 {
          local ss2=6
       }
       if mod(`xx',2)==1 {
          local ss2=5
       }
       local sss=`xx'+2
       local eee=`xx'-2
       forvalues ggg=`sss'(2)`z' {
         local zzz=word("`varlist`xg''",`ggg')
         local xbsum=`xbsum'-`rm`ggg''*_b[`zzz']
       }
       forvalues ggg=`ss2'(2)`eee' {
         local zzz=word("`varlist`xg''",`ggg')
         local xbsum=`xbsum'+(1-`rm`ggg'')*_b[`zzz']
     }
    }
   }
     if `xg'==12 {
       if `xx'==5 {
          local xbsum=`xbsum'-_b[yesBuyerF2]*`rm8' -_b[yesBuyerF4]*`rm10'
       }       
      if `xx'==6 {
         local xbsum=`xbsum'+(1-`rm6')*_b[yesBuyerF]-`rm10'*_b[yesBuyerF4]
       }      
       if `xx'==7 {
          local xbsum=`xbsum'+(1-`rm6')*_b[yesBuyerF]+(1-`rm8')*_b[yesBuyerF2]
       }
     }
     if `xx'~=2 & `xx'~=4 {
         local xbsum=`xbsum'-_b[`zz']*`rm`xx''  /* Set the own variable to 0 */
         local mrgB=exp(`xbsum'+_b[`zz'])/(1+exp(`xbsum'+_b[`zz']))-exp(`xbsum')/(1+exp(`xbsum'))
     }
     if `xx'==2 | `xx'==4 {
         local mrgB=exp(`xbsum')*(1+exp(`xbsum'))^(-2)*_b[`zz']  /* Again, use the formula from the Greene textbook. */
     }
     qui replace `coefname'`x'=`mrgB' in `yyy'/`yyy' 
   }
  ren esamp esamp`x'
  drop esamp*
  list coef* in 1/34
  
 }
}

keep coef* 
keep in 1/34
outsheet using custlistResults`suff'.csv, delim(,) replace
}
}

